==> beast-privilege-api-2.9.12-GS-20241012.081814-7-sources.jar: com/thebeastshop/privilege/vo/LimitProductVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class LimitProductVO implements Serializable {
    private Integer id;

    private Integer prodId;
    private String prodCode;

    private String prodName;

    private Integer channelType;

    private Date startTime;

    private Date endTime;
    private Integer userLimitNum;

    private Integer totalLimitNum;

    private Integer currentBuyNum;

    private String remark;

    private Date createTime;

    private Date updateTime;

    private Integer creatorId;

    private String creatorName;

    private Integer active;

    private Integer prodStatus;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getProdName() {
        return prodName;
    }

    public void setProdName(String prodName) {
        this.prodName = prodName;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getUserLimitNum() {
        return userLimitNum;
    }

    public void setUserLimitNum(Integer userLimitNum) {
        this.userLimitNum = userLimitNum;
    }

    public Integer getTotalLimitNum() {
        return totalLimitNum;
    }

    public void setTotalLimitNum(Integer totalLimitNum) {
        this.totalLimitNum = totalLimitNum;
    }

    public Integer getCurrentBuyNum() {
        return currentBuyNum;
    }

    public void setCurrentBuyNum(Integer currentBuyNum) {
        this.currentBuyNum = currentBuyNum;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public Integer getProdStatus() {
        return prodStatus;
    }

    public void setProdStatus(Integer prodStatus) {
        this.prodStatus = prodStatus;
    }
}

==> beast-privilege-api-3.0-GS-20250710.080540-4-sources.jar: com/thebeastshop/privilege/vo/LimitProductVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class LimitProductVO implements Serializable {
    private Integer id;

    private Integer prodId;
    private String prodCode;

    private String prodName;

    private Integer channelType;

    private Date startTime;

    private Date endTime;
    private Integer userLimitNum;

    private Integer totalLimitNum;

    private Integer userGroupLimitNum;

    private Integer currentBuyNum;

    private String remark;

    private Date createTime;

    private Date updateTime;

    private Integer creatorId;

    private String creatorName;

    private Integer active;

    private Integer prodStatus;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getProdName() {
        return prodName;
    }

    public void setProdName(String prodName) {
        this.prodName = prodName;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getUserLimitNum() {
        return userLimitNum;
    }

    public void setUserLimitNum(Integer userLimitNum) {
        this.userLimitNum = userLimitNum;
    }

    public Integer getTotalLimitNum() {
        return totalLimitNum;
    }

    public void setTotalLimitNum(Integer totalLimitNum) {
        this.totalLimitNum = totalLimitNum;
    }

    public Integer getUserGroupLimitNum() {
        return userGroupLimitNum;
    }

    public void setUserGroupLimitNum(Integer userGroupLimitNum) {
        this.userGroupLimitNum = userGroupLimitNum;
    }

    public Integer getCurrentBuyNum() {
        return currentBuyNum;
    }

    public void setCurrentBuyNum(Integer currentBuyNum) {
        this.currentBuyNum = currentBuyNum;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public Integer getProdStatus() {
        return prodStatus;
    }

    public void setProdStatus(Integer prodStatus) {
        this.prodStatus = prodStatus;
    }
}
